imitation.algorithms package
============================

Subpackages
-----------

.. toctree::

   imitation.algorithms.adversarial

Submodules
----------

imitation.algorithms.bc module
------------------------------

.. automodule:: imitation.algorithms.bc

imitation.algorithms.dagger module
----------------------------------

.. automodule:: imitation.algorithms.dagger

imitation.algorithms.density module
-----------------------------------

.. automodule:: imitation.algorithms.density

imitation.algorithms.mce\_irl module
------------------------------------

.. automodule:: imitation.algorithms.mce_irl


Module contents
---------------

.. automodule:: imitation.algorithms
